# write-data [![NPM version](https://img.shields.io/npm/v/write-data.svg?style=flat)](https://www.npmjs.com/package/write-data) [![NPM monthly downloads](https://img.shields.io/npm/dm/write-data.svg?style=flat)](https://npmjs.org/package/write-data) [![NPM total downloads](https://img.shields.io/npm/dt/write-data.svg?style=flat)](https://npmjs.org/package/write-data) [![Linux Build Status](https://img.shields.io/travis/jonschlinkert/write-data.svg?style=flat&label=Travis)](https://travis-ci.org/jonschlinkert/write-data)

> Write a YAML or JSON file to disk. Automatically detects the format to write based on extension. Or pass `ext` on the options.

Please consider following this project's author, [Jon Schlinkert](https://github.com/jonschlinkert), and consider starring the project to show your :heart: and support.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install --save write-data
```

## Usage

Add to your node.js application with the following line of code:

```js
var writeData = require('write-data');

// async
writeData(filepath, data[, options], function(err) {
  // do stuff with "err"
});

// sync
writeData.sync(filepath, data[, options]);
```

## API

The file extension is used to detect the data format to write. This can be overriden by passing a value on `options.ext`.

### YAML examples

```js
var data = {language: 'node_js', node_js: ['0.10', '0.12']};

// async
writeData('.travis.yml', data, function(err) {
  // do stuff with "err"
});

// sync
writeData.sync('.travis.yml', data);
```

Both would write a `.travis.yml` file to disk with the following contents:

```yaml
language: node_js
node_js:
  - "0.10"
  - "0.12"
```

### JSON examples

```js
var data = { name: 'foo', version: '0.1.0' };

// async
writeData('package.json', data, function(err) {
  // do stuff with "err"
});

// sync
writeData.sync('package.json', data);
```

Both would write a `package.json` file to disk with the following contents:

```json
{ 
  "name": "foo", 
  "version": "0.1.0" 
}
```

## About

<details>
<summary><strong>Contributing</strong></summary>

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

</details>

<details>
<summary><strong>Running Tests</strong></summary>

Running and reviewing unit tests is a great way to get familiarized with a library and its API. You can install dependencies and run tests with the following command:

```sh
$ npm install && npm test
```

</details>

<details>
<summary><strong>Building docs</strong></summary>

_(This project's readme.md is generated by [verb](https://github.com/verbose/verb-generate-readme), please don't edit the readme directly. Any changes to the readme must be made in the [.verb.md](.verb.md) readme template.)_

To generate the readme, run the following command:

```sh
$ npm install -g verbose/verb#dev verb-generate-readme && verb
```

</details>

### Related projects

You might also be interested in these projects:

* [delete](https://www.npmjs.com/package/delete): Delete files and folders and any intermediate directories if they exist (sync and async). | [homepage](https://github.com/jonschlinkert/delete "Delete files and folders and any intermediate directories if they exist (sync and async).")
* [read-data](https://www.npmjs.com/package/read-data): Read JSON or YAML files. | [homepage](https://github.com/jonschlinkert/read-data "Read JSON or YAML files.")
* [read-yaml](https://www.npmjs.com/package/read-yaml): Very thin wrapper around js-yaml for directly reading in YAML files. | [homepage](https://github.com/jonschlinkert/read-yaml "Very thin wrapper around js-yaml for directly reading in YAML files.")
* [write-json](https://www.npmjs.com/package/write-json): Write a JSON file to disk, also creates intermediate directories in the destination path if… [more](https://github.com/jonschlinkert/write-json) | [homepage](https://github.com/jonschlinkert/write-json "Write a JSON file to disk, also creates intermediate directories in the destination path if they don't already exist.")
* [write-yaml](https://www.npmjs.com/package/write-yaml): Write YAML. Converts JSON to YAML writes it to the specified file. | [homepage](https://github.com/jonschlinkert/write-yaml "Write YAML. Converts JSON to YAML writes it to the specified file.")
* [write](https://www.npmjs.com/package/write): Write data to a file, replacing the file if it already exists and creating any… [more](https://github.com/jonschlinkert/write) | [homepage](https://github.com/jonschlinkert/write "Write data to a file, replacing the file if it already exists and creating any intermediate directories if they don't already exist. Thin wrapper around node's native fs methods.")

### Author

**Jon Schlinkert**

* [linkedin/in/jonschlinkert](https://linkedin.com/in/jonschlinkert)
* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](https://twitter.com/jonschlinkert)

### License

Copyright © 2018, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT License](LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.6.0, on January 26, 2018._